#
# Flask-Turbo
#
# Copyright (C) 2021 Boris Raicheff
# All rights reserved
#


from setuptools import setup


setup(
    name='Flask-Turbo',
    version='0.0.0',
    description='Flask-Turbo',
    author='Boris Raicheff',
    author_email='b@raicheff.com',
    url='https://github.com/raicheff/flask-turbo',
    py_modules=['flask_turbo'],
)


# EOF
